## fallible features

These additional features have been included in this release of fallible:


- [86241 - Register projections and action plugin dynamic host/group/var API](https://github.com/ansible/ansible/pull/86241)
